Module cpu_cycles_reader::ffi

source ·
Base bindings to c code

Unless you are really sure you have to use them, just use crate::CyclesReader for normal purpose

Structs

  • The Raw Reader Structure, corresponding to the same structure in C

Functions