pub unsafe extern "C" fn readCyclesReader(
reader: *mut CyclesReaderRaw,
cpu: c_int,
) -> c_llExpand description
This C function reads Cycles information by reading the file identifier, see perf_event_read
The returned array pointer is also allocated by malloc, consider calling libc::free to release to ensure memory safety, and remember to prevent dangling pointers
NOTE: The length of the array is the number of CPUs used during construction. Consider using the size member of self::CyclesReaderRaw to determine the length of the array