CyclesInstant

Struct CyclesInstant 

pub struct CyclesInstant { /* private fields */ }

Implementations

Source

impl CyclesInstant

pub fn cycles_since(&self, other: Self) -> Cycles

Calculate the number of cpu cycles between two recordings

Panics

If the two records are not the same cpu, an error will be returned.

pub fn cycles_since_checked(&self, other: Self) -> Result<Cycles>

Calculate the number of cpu cycles between two recordings

Errors

If the two records are not the same cpu, an error will be returned