Module cpu_cycles_reader::ffi
source · Expand description
Base bindings to c code
Unless you are really sure you have to use them, just use crate::CyclesReader for normal purpose
Structs
- The Raw Reader Structure, corresponding to the same structure in C
Functions
- Mock constructor
- Mock destructor
- This C function calls ioctl to stop recording Cycles, see perf_event_read
- This C function calls ioctl to start recording Cycles, see perf_event_read
- This C function reads Cycles information by reading the file identifier, see perf_event_read